@@ -104,8 +104,9 @@ public class FileHeaderFactory {
   private byte[] determineGeneralPurposeBitFlag(boolean isEncrypted, ZipParameters zipParameters, Charset charset) {
     byte[] generalPurposeBitFlag = new byte[2];
     generalPurposeBitFlag[0] = generateFirstGeneralPurposeByte(isEncrypted, zipParameters);
-    if(charset.equals(InternalZipConstants.CHARSET_UTF_8)) {
-      generalPurposeBitFlag[1] = setBit(generalPurposeBitFlag[1], 3); // set 3rd bit which corresponds to utf-8 file name charset
+    if(charset == null || InternalZipConstants.CHARSET_UTF_8.equals(charset)) {
+      // set 3rd bit which corresponds to utf-8 file name charset
+      generalPurposeBitFlag[1] = setBit(generalPurposeBitFlag[1], 3);
     }
     return generalPurposeBitFlag;
   }
@@ -171,6 +172,6 @@ public class FileHeaderFactory {
   }
 
   private int determineFileNameLength(String fileName, Charset charset) {
-    return fileName.getBytes(charset).length;
+    return HeaderUtil.getBytesFromString(fileName, charset).length;
   }
 }
