@@ -37,6 +37,7 @@ import java.io.OutputStream;
 import java.nio.charset.Charset;
 import java.util.List;
 
+import static net.lingala.zip4j.headers.HeaderUtil.getBytesFromString;
 import static net.lingala.zip4j.util.FileUtils.getZipFileNameWithoutExtension;
 import static net.lingala.zip4j.util.InternalZipConstants.ZIP_64_NUMBER_OF_ENTRIES_LIMIT;
 import static net.lingala.zip4j.util.InternalZipConstants.ZIP_64_SIZE_LIMIT;
@@ -48,9 +49,9 @@ public class HeaderWriter {
   private static final short ZIP64_EXTRA_DATA_RECORD_SIZE_FH = 28;
   private static final short AES_EXTRA_DATA_RECORD_SIZE = 11;
 
-  private RawIO rawIO = new RawIO();
-  private byte[] longBuff = new byte[8];
-  private byte[] intBuff = new byte[4];
+  private final RawIO rawIO = new RawIO();
+  private final byte[] longBuff = new byte[8];
+  private final byte[] intBuff = new byte[4];
 
   public void writeLocalFileHeader(ZipModel zipModel, LocalFileHeader localFileHeader, OutputStream outputStream,
                                    Charset charset) throws IOException {
@@ -92,7 +93,7 @@ public class HeaderWriter {
 
       byte[] fileNameBytes = new byte[0];
       if (isStringNotNullAndNotEmpty(localFileHeader.getFileName())) {
-        fileNameBytes = localFileHeader.getFileName().getBytes(charset);
+        fileNameBytes = getBytesFromString(localFileHeader.getFileName(), charset);
       }
       rawIO.writeShortLittleEndian(byteArrayOutputStream, fileNameBytes.length);
 
@@ -262,7 +263,10 @@ public class HeaderWriter {
     if (fileHeader.getDiskNumberStart() != outputStream.getCurrentSplitFileCounter()) {
       String parentFile = zipModel.getZipFile().getParent();
       String fileNameWithoutExt = getZipFileNameWithoutExtension(zipModel.getZipFile().getName());
-      String fileName = parentFile + System.getProperty("file.separator");
+      String fileName = "";
+      if (parentFile != null) {
+        fileName = parentFile + System.getProperty("file.separator");
+      }
       if (fileHeader.getDiskNumberStart() < 9) {
         fileName += fileNameWithoutExt + ".z0" + (fileHeader.getDiskNumberStart() + 1);
       } else {
@@ -336,7 +340,9 @@ public class HeaderWriter {
     return ((CountingOutputStream) outputStream).getCurrentSplitFileCounter();
   }
 
-  private void writeZipHeaderBytes(ZipModel zipModel, OutputStream outputStream, byte[] buff, Charset charset) throws IOException {
+  private void writeZipHeaderBytes(ZipModel zipModel, OutputStream outputStream, byte[] buff, Charset charset)
+      throws IOException {
+
     if (buff == null) {
       throw new ZipException("invalid buff to write as zip headers");
     }
@@ -377,8 +383,8 @@ public class HeaderWriter {
     zipModel.getEndOfCentralDirectoryRecord().setNumberOfThisDiskStartOfCentralDir(currentSplitFileCounter);
   }
 
-  private void writeCentralDirectory(ZipModel zipModel, ByteArrayOutputStream byteArrayOutputStream, RawIO rawIO, Charset charset)
-      throws ZipException {
+  private void writeCentralDirectory(ZipModel zipModel, ByteArrayOutputStream byteArrayOutputStream, RawIO rawIO,
+                                     Charset charset) throws ZipException {
 
     if (zipModel.getCentralDirectory() == null || zipModel.getCentralDirectory().getFileHeaders() == null
         || zipModel.getCentralDirectory().getFileHeaders().size() <= 0) {
@@ -426,7 +432,7 @@ public class HeaderWriter {
 
       byte[] fileNameBytes = new byte[0];
       if (isStringNotNullAndNotEmpty(fileHeader.getFileName())) {
-        fileNameBytes = fileHeader.getFileName().getBytes(charset);
+        fileNameBytes = getBytesFromString(fileHeader.getFileName(), charset);
       }
       rawIO.writeShortLittleEndian(byteArrayOutputStream, fileNameBytes.length);
 
@@ -447,7 +453,7 @@ public class HeaderWriter {
       String fileComment = fileHeader.getFileComment();
       byte[] fileCommentBytes = new byte[0];
       if (isStringNotNullAndNotEmpty(fileComment)) {
-        fileCommentBytes = fileComment.getBytes(charset);
+        fileCommentBytes = getBytesFromString(fileComment, charset);
       }
       rawIO.writeShortLittleEndian(byteArrayOutputStream, fileCommentBytes.length);
 
@@ -509,7 +515,7 @@ public class HeaderWriter {
     }
   }
 
-  private int calculateExtraDataRecordsSize(FileHeader fileHeader, boolean writeZip64ExtendedInfo) throws IOException {
+  private int calculateExtraDataRecordsSize(FileHeader fileHeader, boolean writeZip64ExtendedInfo) {
     int extraFieldLength = 0;
 
     if (writeZip64ExtendedInfo) {
@@ -534,7 +540,8 @@ public class HeaderWriter {
     return extraFieldLength;
   }
 
-  private void writeRemainingExtraDataRecordsIfPresent(FileHeader fileHeader, OutputStream outputStream) throws IOException {
+  private void writeRemainingExtraDataRecordsIfPresent(FileHeader fileHeader, OutputStream outputStream)
+      throws IOException {
     if (fileHeader.getExtraDataRecords() == null || fileHeader.getExtraDataRecords().size() == 0) {
       return;
     }
@@ -582,7 +589,8 @@ public class HeaderWriter {
   }
 
   private void writeEndOfCentralDirectoryRecord(ZipModel zipModel, int sizeOfCentralDir, long offsetCentralDir,
-                                                ByteArrayOutputStream byteArrayOutputStream, RawIO rawIO, Charset charset)
+                                                ByteArrayOutputStream byteArrayOutputStream, RawIO rawIO,
+                                                Charset charset)
       throws IOException {
 
     byte[] longByte = new byte[8];
@@ -620,7 +628,7 @@ public class HeaderWriter {
 
     String comment = zipModel.getEndOfCentralDirectoryRecord().getComment();
     if (isStringNotNullAndNotEmpty(comment)) {
-      byte[] commentBytes = comment.getBytes(charset);
+      byte[] commentBytes = getBytesFromString(comment, charset);
       rawIO.writeShortLittleEndian(byteArrayOutputStream, commentBytes.length);
       byteArrayOutputStream.write(commentBytes);
     } else {
@@ -693,4 +701,4 @@ public class HeaderWriter {
 
     return zip64EndOfCentralDirectoryRecord;
   }
-}
\ No newline at end of file
+}
