@@ -1,7 +1,6 @@
 package net.lingala.zip4j.io.inputstream;
 
 import net.lingala.zip4j.crypto.StandardDecrypter;
-import net.lingala.zip4j.exception.ZipException;
 import net.lingala.zip4j.model.LocalFileHeader;
 
 import java.io.IOException;
@@ -10,13 +9,15 @@ import static net.lingala.zip4j.util.InternalZipConstants.STD_DEC_HDR_SIZE;
 
 class ZipStandardCipherInputStream extends CipherInputStream<StandardDecrypter> {
 
-  public ZipStandardCipherInputStream(ZipEntryInputStream zipEntryInputStream, LocalFileHeader localFileHeader, char[] password) throws IOException, ZipException {
-    super(zipEntryInputStream, localFileHeader, password);
+  public ZipStandardCipherInputStream(ZipEntryInputStream zipEntryInputStream, LocalFileHeader localFileHeader,
+                                      char[] password, int bufferSize) throws IOException {
+    super(zipEntryInputStream, localFileHeader, password, bufferSize);
   }
 
   @Override
-  protected StandardDecrypter initializeDecrypter(LocalFileHeader localFileHeader, char[] password) throws ZipException, IOException {
-    return new StandardDecrypter(password, localFileHeader.getCrcRawData(), getStandardDecrypterHeaderBytes());
+  protected StandardDecrypter initializeDecrypter(LocalFileHeader localFileHeader, char[] password) throws IOException {
+    return new StandardDecrypter(password, localFileHeader.getCrc(), localFileHeader.getLastModifiedTime(),
+        getStandardDecrypterHeaderBytes());
   }
 
   private byte[] getStandardDecrypterHeaderBytes() throws IOException {
