@@ -18,7 +18,6 @@ import java.io.OutputStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
-import java.util.regex.Matcher;
 
 import static net.lingala.zip4j.util.InternalZipConstants.FILE_SEPARATOR;
 
@@ -140,7 +139,7 @@ public abstract class AbstractExtractFileTask<T> extends AsyncZipTask<T> {
           "Zip4j does not support Strong Encryption, as this is patented.");
     }
 
-    LocalFileHeader localFileHeader = zipInputStream.getNextEntry(fileHeader);
+    LocalFileHeader localFileHeader = zipInputStream.getNextEntry(fileHeader, false);
 
     if (localFileHeader == null) {
       throw new ZipException("Could not read corresponding local file header for file header: "
@@ -159,21 +158,13 @@ public abstract class AbstractExtractFileTask<T> extends AsyncZipTask<T> {
   }
 
   private File determineOutputFile(FileHeader fileHeader, String outputPath, String newFileName) {
-    String outputFileName;
+    String outputFileName = fileHeader.getFileName();
     if (Zip4jUtil.isStringNotNullAndNotEmpty(newFileName)) {
       outputFileName = newFileName;
-    } else {
-      // replace all slashes with file separator
-      outputFileName = getFileNameWithSystemFileSeparators(fileHeader.getFileName());
     }
-
     return new File(outputPath + FILE_SEPARATOR + outputFileName);
   }
 
-  private String getFileNameWithSystemFileSeparators(String fileNameToReplace) {
-    return fileNameToReplace.replaceAll("[/\\\\]", Matcher.quoteReplacement(FILE_SEPARATOR));
-  }
-
   @Override
   protected ProgressMonitor.Task getTask() {
     return ProgressMonitor.Task.EXTRACT_ENTRY;
