@@ -3,30 +3,32 @@ package net.lingala.zip4j.tasks;
 import net.lingala.zip4j.io.inputstream.SplitInputStream;
 import net.lingala.zip4j.io.inputstream.ZipInputStream;
 import net.lingala.zip4j.model.FileHeader;
+import net.lingala.zip4j.model.UnzipParameters;
+import net.lingala.zip4j.model.Zip4jConfig;
 import net.lingala.zip4j.model.ZipModel;
 import net.lingala.zip4j.progress.ProgressMonitor;
 import net.lingala.zip4j.tasks.ExtractAllFilesTask.ExtractAllFilesTaskParameters;
 import net.lingala.zip4j.util.UnzipUtil;
 
 import java.io.IOException;
-import java.nio.charset.Charset;
 
 import static net.lingala.zip4j.headers.HeaderUtil.getTotalUncompressedSizeOfAllFileHeaders;
 
 public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFilesTaskParameters> {
 
-  private char[] password;
+  private final char[] password;
   private SplitInputStream splitInputStream;
 
-  public ExtractAllFilesTask(ZipModel zipModel, char[] password, AsyncTaskParameters asyncTaskParameters) {
-    super(zipModel, asyncTaskParameters);
+  public ExtractAllFilesTask(ZipModel zipModel, char[] password, UnzipParameters unzipParameters,
+                             AsyncTaskParameters asyncTaskParameters) {
+    super(zipModel, unzipParameters, asyncTaskParameters);
     this.password = password;
   }
 
   @Override
   protected void executeTask(ExtractAllFilesTaskParameters taskParameters, ProgressMonitor progressMonitor)
       throws IOException {
-    try (ZipInputStream zipInputStream = prepareZipInputStream(taskParameters.charset)) {
+    try (ZipInputStream zipInputStream = prepareZipInputStream(taskParameters.zip4jConfig)) {
       for (FileHeader fileHeader : getZipModel().getCentralDirectory().getFileHeaders()) {
         if (fileHeader.getFileName().startsWith("__MACOSX")) {
           progressMonitor.updateWorkCompleted(fileHeader.getUncompressedSize());
@@ -35,7 +37,8 @@ public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFiles
 
         splitInputStream.prepareExtractionForFileHeader(fileHeader);
 
-        extractFile(zipInputStream, fileHeader, taskParameters.outputPath, null, progressMonitor);
+        byte[] readBuff = new byte[taskParameters.zip4jConfig.getBufferSize()];
+        extractFile(zipInputStream, fileHeader, taskParameters.outputPath, null, progressMonitor, readBuff);
         verifyIfTaskIsCancelled();
       }
     } finally {
@@ -50,7 +53,7 @@ public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFiles
     return getTotalUncompressedSizeOfAllFileHeaders(getZipModel().getCentralDirectory().getFileHeaders());
   }
 
-  private ZipInputStream prepareZipInputStream(Charset charset) throws IOException {
+  private ZipInputStream prepareZipInputStream(Zip4jConfig zip4jConfig) throws IOException {
     splitInputStream = UnzipUtil.createSplitInputStream(getZipModel());
 
     FileHeader fileHeader = getFirstFileHeader(getZipModel());
@@ -58,7 +61,7 @@ public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFiles
       splitInputStream.prepareExtractionForFileHeader(fileHeader);
     }
 
-    return new ZipInputStream(splitInputStream, password, charset);
+    return new ZipInputStream(splitInputStream, password, zip4jConfig);
   }
 
   private FileHeader getFirstFileHeader(ZipModel zipModel) {
@@ -72,10 +75,10 @@ public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFiles
   }
 
   public static class ExtractAllFilesTaskParameters extends AbstractZipTaskParameters {
-    private String outputPath;
+    private final String outputPath;
 
-    public ExtractAllFilesTaskParameters(String outputPath, Charset charset) {
-      super(charset);
+    public ExtractAllFilesTaskParameters(String outputPath, Zip4jConfig zip4jConfig) {
+      super(zip4jConfig);
       this.outputPath = outputPath;
     }
   }
