@@ -7,6 +7,7 @@ import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.progress.ProgressMonitor;
 
 import java.io.File;
+import java.io.FilenameFilter;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.io.RandomAccessFile;
@@ -34,15 +35,15 @@ import static java.nio.file.attribute.PosixFilePermission.OWNER_EXECUTE;
 import static java.nio.file.attribute.PosixFilePermission.OWNER_READ;
 import static java.nio.file.attribute.PosixFilePermission.OWNER_WRITE;
 import static net.lingala.zip4j.util.BitUtils.isBitSet;
-import static net.lingala.zip4j.util.InternalZipConstants.BUFF_SIZE;
+import static net.lingala.zip4j.util.BitUtils.setBit;
 import static net.lingala.zip4j.util.InternalZipConstants.FILE_SEPARATOR;
 import static net.lingala.zip4j.util.InternalZipConstants.ZIP_FILE_SEPARATOR;
 import static net.lingala.zip4j.util.Zip4jUtil.isStringNotNullAndNotEmpty;
 
 public class FileUtils {
 
-  public static final byte[] DEFAULT_POSIX_FILE_ATTRIBUTES = new byte[] {0, 0, -128, -127}; //-rw-------
-  public static final byte[] DEFAULT_POSIX_FOLDER_ATTRIBUTES = new byte[] {0, 0, -128, 65}; //drw-------
+  public static final byte[] DEFAULT_POSIX_FILE_ATTRIBUTES = new byte[] {0, 0, -92, -127}; //-rw-r--r--
+  public static final byte[] DEFAULT_POSIX_FOLDER_ATTRIBUTES = new byte[] {0, 0, -19, 65}; //drwxr-xr-x
 
   public static void setFileAttributes(Path file, byte[] fileAttributes) {
     if (fileAttributes == null || fileAttributes.length == 0) {
@@ -232,11 +233,11 @@ public class FileUtils {
         File tmpFile = new File(fileCanonicalPath);
 
         if (tmpFile.isDirectory()) {
-          tmpFileName = tmpFileName.replaceAll("\\\\", "/");
+          tmpFileName = tmpFileName.replaceAll("\\\\", ZIP_FILE_SEPARATOR);
           tmpFileName += ZIP_FILE_SEPARATOR;
         } else {
           String bkFileName = tmpFileName.substring(0, tmpFileName.lastIndexOf(tmpFile.getName()));
-          bkFileName = bkFileName.replaceAll("\\\\", "/");
+          bkFileName = bkFileName.replaceAll("\\\\", ZIP_FILE_SEPARATOR);
           tmpFileName = bkFileName + getNameOfFileInZip(tmpFile, zipParameters.getFileNameInZip());
         }
 
@@ -262,6 +263,22 @@ public class FileUtils {
       fileName = rootFolderNameInZip + fileName;
     }
 
+    if (!isStringNotNullAndNotEmpty(fileName)) {
+      String errorMessage = "fileName to add to zip is empty or null. fileName: '" + fileName + "' "
+          + "DefaultFolderPath: '" + zipParameters.getDefaultFolderPath() + "' "
+          + "FileNameInZip: " + zipParameters.getFileNameInZip();
+
+      if (isSymbolicLink(fileToAdd)) {
+        errorMessage += "isSymlink: true ";
+      }
+
+      if (Zip4jUtil.isStringNotNullAndNotEmpty(rootFolderNameInZip)) {
+        errorMessage = "rootFolderNameInZip: '" + rootFolderNameInZip + "' ";
+      }
+
+      throw new ZipException(errorMessage);
+    }
+
     return fileName;
   }
 
@@ -282,7 +299,7 @@ public class FileUtils {
   }
 
   public static void copyFile(RandomAccessFile randomAccessFile, OutputStream outputStream, long start, long end,
-                              ProgressMonitor progressMonitor) throws ZipException {
+                              ProgressMonitor progressMonitor, int bufferSize) throws ZipException {
 
     if (start < 0 || end < 0 || start > end) {
       throw new ZipException("invalid offsets");
@@ -300,10 +317,10 @@ public class FileUtils {
       long bytesRead = 0;
       long bytesToRead = end - start;
 
-      if ((end - start) < BUFF_SIZE) {
+      if ((end - start) < bufferSize) {
         buff = new byte[(int) bytesToRead];
       } else {
-        buff = new byte[BUFF_SIZE];
+        buff = new byte[bufferSize];
       }
 
       while ((readLen = randomAccessFile.read(buff)) != -1) {
@@ -365,8 +382,13 @@ public class FileUtils {
    * @return sorted list of split files. Returns an empty list if no files of that pattern are found in the current directory
    */
   public static File[] getAllSortedNumberedSplitFiles(File firstNumberedFile) {
-    String zipFileNameWithoutExtension = FileUtils.getFileNameWithoutExtension(firstNumberedFile.getName());
-    File[] allSplitFiles = firstNumberedFile.getParentFile().listFiles((dir, name) -> name.startsWith(zipFileNameWithoutExtension + "."));
+    final String zipFileNameWithoutExtension = FileUtils.getFileNameWithoutExtension(firstNumberedFile.getName());
+    File[] allSplitFiles = firstNumberedFile.getParentFile().listFiles(new FilenameFilter() {
+      @Override
+      public boolean accept(File dir, String name) {
+        return name.startsWith(zipFileNameWithoutExtension + ".");
+      }
+    });
 
     if(allSplitFiles == null) {
       return new File[0];
@@ -405,6 +427,8 @@ public class FileUtils {
       } else {
         System.arraycopy(DEFAULT_POSIX_FILE_ATTRIBUTES, 0, permissions, 0, permissions.length);
       }
+    } else if (isWindows() && isDirectory) {
+      permissions[0] = setBit(permissions[0], 4);
     }
     return permissions;
   }
@@ -487,6 +511,7 @@ public class FileUtils {
       windowsAttribute = setBitIfApplicable(dosFileAttributes.isReadOnly(), windowsAttribute, 0);
       windowsAttribute = setBitIfApplicable(dosFileAttributes.isHidden(), windowsAttribute, 1);
       windowsAttribute = setBitIfApplicable(dosFileAttributes.isSystem(), windowsAttribute, 2);
+      windowsAttribute = setBitIfApplicable(dosFileAttributes.isDirectory(), windowsAttribute, 4);
       windowsAttribute = setBitIfApplicable(dosFileAttributes.isArchive(), windowsAttribute, 5);
       fileAttributes[0] = windowsAttribute;
     } catch (IOException e) {
