@@ -5,6 +5,7 @@ import net.lingala.zip4j.model.AESExtraDataRecord;
 import net.lingala.zip4j.model.FileHeader;
 import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.model.enums.AesKeyStrength;
+import net.lingala.zip4j.model.enums.CompressionLevel;
 import net.lingala.zip4j.model.enums.CompressionMethod;
 import net.lingala.zip4j.model.enums.EncryptionMethod;
 import net.lingala.zip4j.testutils.TestUtils;
@@ -27,6 +28,7 @@ import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.List;
 
+import static net.lingala.zip4j.testutils.TestUtils.createSymlink;
 import static net.lingala.zip4j.testutils.TestUtils.getTestFileFromResources;
 import static net.lingala.zip4j.testutils.ZipFileVerifier.verifyZipFileByExtractingAllFiles;
 import static org.assertj.core.api.Assertions.assertThat;
@@ -482,6 +484,43 @@ public class CreateZipFileIT extends AbstractIT {
         "test-folder/sub-folder2/symlink.link");
   }
 
+  @Test
+  public void testEncryptWithZipStrongEncryptionThrowsException() throws ZipException {
+    ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setEncryptionMethod(EncryptionMethod.ZIP_STANDARD_VARIANT_STRONG);
+    zipParameters.setEncryptFiles(true);
+
+    expectedException.expect(ZipException.class);
+    expectedException.expectMessage("ZIP_STANDARD_VARIANT_STRONG encryption method is not supported");
+
+    zipFile.addFiles(FILES_TO_ADD, zipParameters);
+  }
+
+  @Test
+  public void testCreateZipFileWithFasterCompressionLevel() throws IOException {
+    createZipFileWithCompressionLevel(CompressionLevel.FASTER);
+    verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 3);
+  }
+
+  @Test
+  public void testCreateZipFileWithMediumFastCompressionLevel() throws IOException {
+    createZipFileWithCompressionLevel(CompressionLevel.MEDIUM_FAST);
+    verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 3);
+  }
+
+  @Test
+  public void testCreateZipFileWithHigherCompressionLevel() throws IOException {
+    createZipFileWithCompressionLevel(CompressionLevel.HIGHER);
+    verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 3);
+  }
+
+  @Test
+  public void testCreateZipFileWithPreUltraCompressionLevel() throws IOException {
+    createZipFileWithCompressionLevel(CompressionLevel.PRE_ULTRA);
+    verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 3);
+  }
+
   private void testAddSymlinkThrowsExceptionForMissingTarget(ZipParameters.SymbolicLinkAction symbolicLinkAction)
       throws IOException {
     File targetFile = Paths.get(temporaryFolder.getRoot().getAbsolutePath(), "foo").toFile();
@@ -566,8 +605,13 @@ public class CreateZipFileIT extends AbstractIT {
     assertThat(aesExtraDataRecord.getAesKeyStrength()).isEqualTo(aesKeyStrength);
   }
 
-  private File[] getAllSplitZipFilesInFolder(File folder, String fileNameWithoutExtension) {
-    FilenameFilter filenameFilter = (dir, name) -> name.contains(fileNameWithoutExtension + ".");
+  private File[] getAllSplitZipFilesInFolder(File folder, final String fileNameWithoutExtension) {
+    FilenameFilter filenameFilter = new FilenameFilter() {
+      @Override
+      public boolean accept(File dir, String name) {
+        return name.contains(fileNameWithoutExtension + ".");
+      }
+    };
     return folder.listFiles(filenameFilter);
   }
 
@@ -602,12 +646,6 @@ public class CreateZipFileIT extends AbstractIT {
     assertThat(generatedTarget).isEqualTo(targetFile);
   }
 
-  private File createSymlink(File targetFile, File rootFolder) throws IOException {
-    Path link = Paths.get(rootFolder.getAbsolutePath(), "symlink.link");
-    Files.createSymbolicLink(link, targetFile.toPath());
-    return link.toFile();
-  }
-
   private File createTestFolderWithSymlinks() throws IOException {
     Path testFolder = temporaryFolder.newFolder("test-folder").toPath();
     Path subFolder1 = Files.createDirectory(Paths.get(testFolder.toString(), "sub-folder1"));
@@ -638,4 +676,11 @@ public class CreateZipFileIT extends AbstractIT {
     }
   }
 
+  private ZipFile createZipFileWithCompressionLevel(CompressionLevel compressionLevel) throws ZipException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setCompressionLevel(compressionLevel);
+    zipFile.addFiles(FILES_TO_ADD, zipParameters);
+    return zipFile;
+  }
 }
