@@ -4,6 +4,7 @@ import net.lingala.zip4j.exception.ZipException;
 import net.lingala.zip4j.model.FileHeader;
 import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.model.enums.AesKeyStrength;
+import net.lingala.zip4j.model.enums.CompressionMethod;
 import net.lingala.zip4j.model.enums.EncryptionMethod;
 import net.lingala.zip4j.testutils.TestUtils;
 import net.lingala.zip4j.testutils.ZipFileVerifier;
@@ -13,15 +14,21 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
 
-import java.io.*;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
 import java.nio.charset.Charset;
 import java.nio.file.Paths;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.Set;
-import java.util.stream.Collectors;
+import java.util.concurrent.ThreadFactory;
 
 import static java.util.Collections.singletonList;
+import static net.lingala.zip4j.testutils.TestUtils.getFileNamesOfFiles;
 import static net.lingala.zip4j.testutils.TestUtils.getTestFileFromResources;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.fail;
@@ -75,8 +82,7 @@ public class MiscZipFileIT extends AbstractIT {
 
     assertThat(fileHeaders).isNotNull();
     assertThat(fileHeaders).hasSize(FILES_TO_ADD.size());
-    List<String> fileNames = FILES_TO_ADD.stream().map(File::getName).collect(Collectors.toList());
-    verifyFileHeadersContainsFiles(fileHeaders, fileNames);
+    verifyFileHeadersContainsFiles(fileHeaders, getFileNamesOfFiles(FILES_TO_ADD));
   }
 
   @Test
@@ -90,7 +96,7 @@ public class MiscZipFileIT extends AbstractIT {
 
     assertThat(fileHeaders).isNotNull();
     assertThat(fileHeaders).hasSize(FILES_TO_ADD.size() + 1);
-    List<String> fileNames = FILES_TO_ADD.stream().map(File::getName).collect(Collectors.toList());
+    List<String> fileNames = getFileNamesOfFiles(FILES_TO_ADD);
     fileNames.add("бореиская.txt");
     verifyFileHeadersContainsFiles(fileHeaders, fileNames);
   }
@@ -478,12 +484,15 @@ public class MiscZipFileIT extends AbstractIT {
   public void testCustomThreadFactory() throws IOException {
     TestUtils.copyFileToFolder(getTestFileFromResources("file_PDF_1MB.pdf"), temporaryFolder.getRoot(), 1000);
 
-    String threadName = "CustomThreadFactoryTest";
+    final String threadName = "CustomThreadFactoryTest";
     ZipFile zipFile = new ZipFile(generatedZipFile);
-    zipFile.setThreadFactory(r -> {
-      Thread t = new Thread(threadName);
-      t.setDaemon(false);
-      return t;
+    zipFile.setThreadFactory(new ThreadFactory() {
+      @Override
+      public Thread newThread(Runnable r) {
+        Thread t = new Thread(threadName);
+        t.setDaemon(false);
+        return t;
+      }
     });
     zipFile.setRunInThread(true);
 
@@ -493,8 +502,7 @@ public class MiscZipFileIT extends AbstractIT {
 
     zipFile.addFolder(temporaryFolder.getRoot(), zipParameters);
 
-    Set<Thread> threadSet = Thread.getAllStackTraces().keySet();
-    List<Thread> zip4jThread = threadSet.stream().filter(e -> e.getName().equals(threadName)).collect(Collectors.toList());
+    List<Thread> zip4jThread = filterForThreadsByName(threadName);
     assertThat(zip4jThread).hasSize(1);
     assertThat(zip4jThread.get(0).getName()).isEqualTo(threadName);
     assertThat(zip4jThread.get(0).isDaemon()).isFalse();
@@ -561,6 +569,81 @@ public class MiscZipFileIT extends AbstractIT {
     assertThat(zipFile.isValidZipFile()).isFalse();
   }
 
+  @Test
+  public void testCloseSuccessfullyClosesAllInputStreams() throws IOException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    zipFile.addFile(TestUtils.getTestFileFromResources("after_deflate_remaining_bytes.bin"));
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setCompressionMethod(CompressionMethod.STORE);
+    zipParameters.setEncryptionMethod(EncryptionMethod.AES);
+    zipFile.addFile(TestUtils.getTestFileFromResources("file_PDF_1MB.pdf"), zipParameters);
+    zipParameters.setEncryptionMethod(EncryptionMethod.ZIP_STANDARD);
+    zipFile.addFile(TestUtils.getTestFileFromResources("sample.pdf"), zipParameters);
+    zipParameters.setCompressionMethod(CompressionMethod.DEFLATE);
+    zipParameters.setEncryptionMethod(EncryptionMethod.AES);
+    zipFile.addFile(TestUtils.getTestFileFromResources("sample_text1.txt"), zipParameters);
+
+    List<InputStream> inputStreams = new ArrayList<>();
+    for (FileHeader fileHeader : zipFile.getFileHeaders()) {
+      inputStreams.add(zipFile.getInputStream(fileHeader));
+    }
+    zipFile.close();
+
+    assertThat(inputStreams).hasSize(4);
+    assertInputStreamsAreClosed(inputStreams);
+  }
+
+  @Test
+  public void testCloseZipFileByTryWithResourceSuccessfullyClosesAllOpenStreams() throws IOException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    zipFile.addFiles(FILES_TO_ADD);
+    List<InputStream> inputStreams = new ArrayList<>();
+
+    try(ZipFile closeableZipFile = new ZipFile(generatedZipFile)) {
+      for (FileHeader fileHeader : closeableZipFile.getFileHeaders()) {
+        inputStreams.add(closeableZipFile.getInputStream(fileHeader));
+      }
+    }
+
+    assertThat(inputStreams).hasSize(3);
+    assertInputStreamsAreClosed(inputStreams);
+  }
+
+  @Test
+  public void testCloseZipFileMultipleTimesClosesAllStreams() throws IOException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    zipFile.addFiles(FILES_TO_ADD);
+    List<InputStream> inputStreams = new ArrayList<>();
+
+    // First open the inputstreams
+    for (FileHeader fileHeader : zipFile.getFileHeaders()) {
+      inputStreams.add(zipFile.getInputStream(fileHeader));
+    }
+    // Close it for the first time
+    zipFile.close();
+    assertInputStreamsAreClosed(inputStreams);
+
+    //Now open an inputstream again
+    InputStream inputStream = zipFile.getInputStream(zipFile.getFileHeader(FILES_TO_ADD.get(0).getName()));
+
+    // Closing it now again should close the inputstream as well
+    zipFile.close();
+
+    assertInputStreamsAreClosed(Collections.singletonList(inputStream));
+  }
+
+  private void assertInputStreamsAreClosed(List<InputStream> inputStreams) {
+    for (InputStream inputStream : inputStreams) {
+      try {
+        //noinspection ResultOfMethodCallIgnored
+        inputStream.read();
+        fail("Should have thrown an exception");
+      } catch (IOException e) {
+        assertThat(e.getMessage()).isEqualTo("Stream closed");
+      }
+    }
+  }
+
   private void verifyInputStream(InputStream inputStream, File fileToCompareAgainst) throws IOException {
     File outputFile = temporaryFolder.newFile();
     try (OutputStream outputStream = new FileOutputStream(outputFile)) {
@@ -596,4 +679,14 @@ public class MiscZipFileIT extends AbstractIT {
     }
   }
 
+  private List<Thread> filterForThreadsByName(String threadName) {
+    Set<Thread> threadSet = Thread.getAllStackTraces().keySet();
+    List<Thread> filteredThreads = new ArrayList<>();
+    for (Thread thread : threadSet) {
+      if (thread.getName().equals(threadName)) {
+        filteredThreads.add(thread);
+      }
+    }
+    return filteredThreads;
+  }
 }
