@@ -2,6 +2,7 @@ package net.lingala.zip4j.util;
 
 import net.lingala.zip4j.AbstractIT;
 import net.lingala.zip4j.exception.ZipException;
+import net.lingala.zip4j.model.ExcludeFileFilter;
 import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.model.enums.RandomAccessFileMode;
 import net.lingala.zip4j.progress.ProgressMonitor;
@@ -22,6 +23,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 
+import static net.lingala.zip4j.util.InternalZipConstants.BUFF_SIZE;
 import static org.assertj.core.api.Assertions.assertThat;
 
 public class FileUtilsIT extends AbstractIT {
@@ -52,7 +54,7 @@ public class FileUtilsIT extends AbstractIT {
     File outputFile = temporaryFolder.newFile();
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(sourceFile, RandomAccessFileMode.READ.getValue());
         OutputStream outputStream = new FileOutputStream(outputFile)) {
-      FileUtils.copyFile(randomAccessFile, outputStream, 100, 100, progressMonitor);
+      FileUtils.copyFile(randomAccessFile, outputStream, 100, 100, progressMonitor, BUFF_SIZE);
     }
 
     assertThat(outputFile.exists()).isTrue();
@@ -65,7 +67,7 @@ public class FileUtilsIT extends AbstractIT {
     File outputFile = temporaryFolder.newFile();
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(sourceFile, RandomAccessFileMode.READ.getValue());
         OutputStream outputStream = new FileOutputStream(outputFile)) {
-      FileUtils.copyFile(randomAccessFile, outputStream, 0, sourceFile.length(), progressMonitor);
+      FileUtils.copyFile(randomAccessFile, outputStream, 0, sourceFile.length(), progressMonitor, BUFF_SIZE);
     }
 
     assertThat(outputFile.length()).isEqualTo(sourceFile.length());
@@ -77,7 +79,7 @@ public class FileUtilsIT extends AbstractIT {
     File outputFile = temporaryFolder.newFile();
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(sourceFile, RandomAccessFileMode.READ.getValue());
         OutputStream outputStream = new FileOutputStream(outputFile)) {
-      FileUtils.copyFile(randomAccessFile, outputStream, 500, 800, progressMonitor);
+      FileUtils.copyFile(randomAccessFile, outputStream, 500, 800, progressMonitor, BUFF_SIZE);
     }
 
     assertThat(outputFile.length()).isEqualTo(300);
@@ -121,11 +123,16 @@ public class FileUtilsIT extends AbstractIT {
   @Test
   public void testGetFilesInDirectoryRecursiveWithExcludeFileFilter() throws IOException {
     File rootFolder = TestUtils.getTestFileFromResources("");
-    List<File> filesToExclude = Arrays.asList(
+    final List<File> filesToExclude = Arrays.asList(
         TestUtils.getTestFileFromResources("бореиская.txt"),
         TestUtils.getTestFileFromResources("sample_directory/favicon.ico")
     );
-    List<File> allFiles = FileUtils.getFilesInDirectoryRecursive(rootFolder, true, true, filesToExclude::contains);
+    List<File> allFiles = FileUtils.getFilesInDirectoryRecursive(rootFolder, true, true, new ExcludeFileFilter() {
+      @Override
+      public boolean isExcluded(File o) {
+        return filesToExclude.contains(o);
+      }
+    });
 
     assertThat(allFiles).hasSize(10);
     for (File file : allFiles) {
@@ -194,7 +201,7 @@ public class FileUtilsIT extends AbstractIT {
     File sourceFile = TestUtils.getTestFileFromResources("sample.pdf");
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(sourceFile, RandomAccessFileMode.READ.getValue());
         OutputStream outputStream = new FileOutputStream(temporaryFolder.newFile())) {
-      FileUtils.copyFile(randomAccessFile, outputStream, start, offset, progressMonitor);
+      FileUtils.copyFile(randomAccessFile, outputStream, start, offset, progressMonitor, BUFF_SIZE);
     }
   }
-}
\ No newline at end of file
+}
